@@ -5,14 +5,14 @@ import (
 	"net/http"
 	"net/http/httptest"
 
-	"github.com/grafana/loki/v3/pkg/logproto"
-	"github.com/grafana/loki/v3/pkg/util"
+	"github.com/grafana/alloy/internal/loki/util"
+	"github.com/grafana/loki/pkg/push"
 )
 
 // RemoteWriteRequest wraps the received logs remote write request that is received.
 type RemoteWriteRequest struct {
 	TenantID string
-	Request  logproto.PushRequest
+	Request  push.PushRequest
 }
 
 // NewRemoteWriteServer creates and starts a new httpserver.Server that can handle remote write request. When a request is handled,
@@ -25,7 +25,7 @@ func NewRemoteWriteServer(receivedChan chan RemoteWriteRequest, status int) *htt
 func createServerHandler(receivedReqsChan chan RemoteWriteRequest, receivedOKStatus int) http.HandlerFunc {
 	return func(rw http.ResponseWriter, req *http.Request) {
 		// Parse the request
-		var pushReq logproto.PushRequest
+		var pushReq push.PushRequest
 		if err := util.ParseProtoReader(req.Context(), req.Body, int(req.ContentLength), math.MaxInt32, &pushReq, util.RawSnappy); err != nil {
 			rw.WriteHeader(500)
 			return
