@@ -39,6 +39,9 @@ func convertRelabelConfig(in []*promv1.RelabelConfig) ([]*relabel.Config, error)
 			outRule.Action = relabel.Action(strings.ToLower(inRule.Action))
 		}
 
+		// TODO: add support for choosing validation scheme: https://github.com/grafana/alloy/issues/4122
+		outRule.NameValidationScheme = model.LegacyValidation
+
 		res = append(res, &outRule)
 	}
 
