@@ -81,10 +81,14 @@ const (
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_INVOCATIONS_PERCENTAGE                              MonthlyUsageAttributionSupportedMetrics = "invocations_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_LAMBDA_TRACED_INVOCATIONS_USAGE                     MonthlyUsageAttributionSupportedMetrics = "lambda_traced_invocations_usage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_LAMBDA_TRACED_INVOCATIONS_PERCENTAGE                MonthlyUsageAttributionSupportedMetrics = "lambda_traced_invocations_percentage"
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_LLM_OBSERVABILITY_USAGE                             MonthlyUsageAttributionSupportedMetrics = "llm_observability_usage"
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_LLM_OBSERVABILITY_PERCENTAGE                        MonthlyUsageAttributionSupportedMetrics = "llm_observability_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_MOBILE_APP_TESTING_USAGE                            MonthlyUsageAttributionSupportedMetrics = "mobile_app_testing_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_MOBILE_APP_TESTING_PERCENTAGE                       MonthlyUsageAttributionSupportedMetrics = "mobile_app_testing_usage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_NDM_NETFLOW_USAGE                                   MonthlyUsageAttributionSupportedMetrics = "ndm_netflow_usage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_NDM_NETFLOW_PERCENTAGE                              MonthlyUsageAttributionSupportedMetrics = "ndm_netflow_percentage"
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_NETWORK_DEVICE_WIRELESS_USAGE                       MonthlyUsageAttributionSupportedMetrics = "network_device_wireless_usage"
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_NETWORK_DEVICE_WIRELESS_PERCENTAGE                  MonthlyUsageAttributionSupportedMetrics = "network_device_wireless_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_NPM_HOST_USAGE                                      MonthlyUsageAttributionSupportedMetrics = "npm_host_usage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_NPM_HOST_PERCENTAGE                                 MonthlyUsageAttributionSupportedMetrics = "npm_host_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_OBS_PIPELINE_BYTES_USAGE                            MonthlyUsageAttributionSupportedMetrics = "obs_pipeline_bytes_usage"
@@ -93,12 +97,16 @@ const (
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_OBS_PIPELINES_VCPU_PERCENTAGE                       MonthlyUsageAttributionSupportedMetrics = "obs_pipelines_vcpu_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_ONLINE_ARCHIVE_USAGE                                MonthlyUsageAttributionSupportedMetrics = "online_archive_usage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_ONLINE_ARCHIVE_PERCENTAGE                           MonthlyUsageAttributionSupportedMetrics = "online_archive_percentage"
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PRODUCT_ANALYTICS_SESSION_USAGE                     MonthlyUsageAttributionSupportedMetrics = "product_analytics_session_usage"
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PRODUCT_ANALYTICS_SESSION_PERCENTAGE                MonthlyUsageAttributionSupportedMetrics = "product_analytics_session_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PROFILED_CONTAINER_USAGE                            MonthlyUsageAttributionSupportedMetrics = "profiled_container_usage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PROFILED_CONTAINER_PERCENTAGE                       MonthlyUsageAttributionSupportedMetrics = "profiled_container_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PROFILED_FARGATE_USAGE                              MonthlyUsageAttributionSupportedMetrics = "profiled_fargate_usage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PROFILED_FARGATE_PERCENTAGE                         MonthlyUsageAttributionSupportedMetrics = "profiled_fargate_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PROFILED_HOST_USAGE                                 MonthlyUsageAttributionSupportedMetrics = "profiled_host_usage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PROFILED_HOST_PERCENTAGE                            MonthlyUsageAttributionSupportedMetrics = "profiled_host_percentage"
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PUBLISHED_APP_USAGE                                 MonthlyUsageAttributionSupportedMetrics = "published_app_usage"
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PUBLISHED_APP_PERCENTAGE                            MonthlyUsageAttributionSupportedMetrics = "published_app_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_SERVERLESS_APPS_USAGE                               MonthlyUsageAttributionSupportedMetrics = "serverless_apps_usage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_SERVERLESS_APPS_PERCENTAGE                          MonthlyUsageAttributionSupportedMetrics = "serverless_apps_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_SNMP_USAGE                                          MonthlyUsageAttributionSupportedMetrics = "snmp_usage"
@@ -141,8 +149,14 @@ const (
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_LOGS_INDEXED_3DAY_PERCENTAGE                        MonthlyUsageAttributionSupportedMetrics = "logs_indexed_3day_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_LOGS_INDEXED_1DAY_USAGE                             MonthlyUsageAttributionSupportedMetrics = "logs_indexed_1day_usage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_LOGS_INDEXED_1DAY_PERCENTAGE                        MonthlyUsageAttributionSupportedMetrics = "logs_indexed_1day_percentage"
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_INGESTED_USAGE                                  MonthlyUsageAttributionSupportedMetrics = "rum_ingested_usage"
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_INGESTED_PERCENTAGE                             MonthlyUsageAttributionSupportedMetrics = "rum_ingested_percentage"
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_INVESTIGATE_USAGE                               MonthlyUsageAttributionSupportedMetrics = "rum_investigate_usage"
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_INVESTIGATE_PERCENTAGE                          MonthlyUsageAttributionSupportedMetrics = "rum_investigate_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_REPLAY_SESSIONS_USAGE                           MonthlyUsageAttributionSupportedMetrics = "rum_replay_sessions_usage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_REPLAY_SESSIONS_PERCENTAGE                      MonthlyUsageAttributionSupportedMetrics = "rum_replay_sessions_percentage"
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_SESSION_REPLAY_ADD_ON_USAGE                     MonthlyUsageAttributionSupportedMetrics = "rum_session_replay_add_on_usage"
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_SESSION_REPLAY_ADD_ON_PERCENTAGE                MonthlyUsageAttributionSupportedMetrics = "rum_session_replay_add_on_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_BROWSER_MOBILE_SESSIONS_USAGE                   MonthlyUsageAttributionSupportedMetrics = "rum_browser_mobile_sessions_usage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_BROWSER_MOBILE_SESSIONS_PERCENTAGE              MonthlyUsageAttributionSupportedMetrics = "rum_browser_mobile_sessions_percentage"
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_INGESTED_SPANS_BYTES_USAGE                          MonthlyUsageAttributionSupportedMetrics = "ingested_spans_bytes_usage"
@@ -225,10 +239,14 @@ var allowedMonthlyUsageAttributionSupportedMetricsEnumValues = []MonthlyUsageAtt
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_INVOCATIONS_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_LAMBDA_TRACED_INVOCATIONS_USAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_LAMBDA_TRACED_INVOCATIONS_PERCENTAGE,
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_LLM_OBSERVABILITY_USAGE,
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_LLM_OBSERVABILITY_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_MOBILE_APP_TESTING_USAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_MOBILE_APP_TESTING_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_NDM_NETFLOW_USAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_NDM_NETFLOW_PERCENTAGE,
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_NETWORK_DEVICE_WIRELESS_USAGE,
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_NETWORK_DEVICE_WIRELESS_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_NPM_HOST_USAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_NPM_HOST_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_OBS_PIPELINE_BYTES_USAGE,
@@ -237,12 +255,16 @@ var allowedMonthlyUsageAttributionSupportedMetricsEnumValues = []MonthlyUsageAtt
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_OBS_PIPELINES_VCPU_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_ONLINE_ARCHIVE_USAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_ONLINE_ARCHIVE_PERCENTAGE,
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PRODUCT_ANALYTICS_SESSION_USAGE,
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PRODUCT_ANALYTICS_SESSION_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PROFILED_CONTAINER_USAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PROFILED_CONTAINER_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PROFILED_FARGATE_USAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PROFILED_FARGATE_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PROFILED_HOST_USAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PROFILED_HOST_PERCENTAGE,
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PUBLISHED_APP_USAGE,
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_PUBLISHED_APP_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_SERVERLESS_APPS_USAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_SERVERLESS_APPS_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_SNMP_USAGE,
@@ -285,8 +307,14 @@ var allowedMonthlyUsageAttributionSupportedMetricsEnumValues = []MonthlyUsageAtt
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_LOGS_INDEXED_3DAY_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_LOGS_INDEXED_1DAY_USAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_LOGS_INDEXED_1DAY_PERCENTAGE,
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_INGESTED_USAGE,
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_INGESTED_PERCENTAGE,
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_INVESTIGATE_USAGE,
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_INVESTIGATE_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_REPLAY_SESSIONS_USAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_REPLAY_SESSIONS_PERCENTAGE,
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_SESSION_REPLAY_ADD_ON_USAGE,
+	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_SESSION_REPLAY_ADD_ON_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_BROWSER_MOBILE_SESSIONS_USAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_RUM_BROWSER_MOBILE_SESSIONS_PERCENTAGE,
 	MONTHLYUSAGEATTRIBUTIONSUPPORTEDMETRICS_INGESTED_SPANS_BYTES_USAGE,
