@@ -665,6 +665,10 @@ func (a *MonitorsApi) GetMonitorNotificationRule(ctx _context.Context, ruleId st
 
 // GetMonitorNotificationRulesOptionalParameters holds optional parameters for GetMonitorNotificationRules.
 type GetMonitorNotificationRulesOptionalParameters struct {
+	Page    *int32
+	PerPage *int32
+	Sort    *string
+	Filters *string
 	Include *string
 }
 
@@ -674,6 +678,30 @@ func NewGetMonitorNotificationRulesOptionalParameters() *GetMonitorNotificationR
 	return &this
 }
 
+// WithPage sets the corresponding parameter name and returns the struct.
+func (r *GetMonitorNotificationRulesOptionalParameters) WithPage(page int32) *GetMonitorNotificationRulesOptionalParameters {
+	r.Page = &page
+	return r
+}
+
+// WithPerPage sets the corresponding parameter name and returns the struct.
+func (r *GetMonitorNotificationRulesOptionalParameters) WithPerPage(perPage int32) *GetMonitorNotificationRulesOptionalParameters {
+	r.PerPage = &perPage
+	return r
+}
+
+// WithSort sets the corresponding parameter name and returns the struct.
+func (r *GetMonitorNotificationRulesOptionalParameters) WithSort(sort string) *GetMonitorNotificationRulesOptionalParameters {
+	r.Sort = &sort
+	return r
+}
+
+// WithFilters sets the corresponding parameter name and returns the struct.
+func (r *GetMonitorNotificationRulesOptionalParameters) WithFilters(filters string) *GetMonitorNotificationRulesOptionalParameters {
+	r.Filters = &filters
+	return r
+}
+
 // WithInclude sets the corresponding parameter name and returns the struct.
 func (r *GetMonitorNotificationRulesOptionalParameters) WithInclude(include string) *GetMonitorNotificationRulesOptionalParameters {
 	r.Include = &include
@@ -707,6 +735,18 @@ func (a *MonitorsApi) GetMonitorNotificationRules(ctx _context.Context, o ...Get
 	localVarHeaderParams := make(map[string]string)
 	localVarQueryParams := _neturl.Values{}
 	localVarFormParams := _neturl.Values{}
+	if optionalParams.Page != nil {
+		localVarQueryParams.Add("page", datadog.ParameterToString(*optionalParams.Page, ""))
+	}
+	if optionalParams.PerPage != nil {
+		localVarQueryParams.Add("per_page", datadog.ParameterToString(*optionalParams.PerPage, ""))
+	}
+	if optionalParams.Sort != nil {
+		localVarQueryParams.Add("sort", datadog.ParameterToString(*optionalParams.Sort, ""))
+	}
+	if optionalParams.Filters != nil {
+		localVarQueryParams.Add("filters", datadog.ParameterToString(*optionalParams.Filters, ""))
+	}
 	if optionalParams.Include != nil {
 		localVarQueryParams.Add("include", datadog.ParameterToString(*optionalParams.Include, ""))
 	}
