@@ -27,10 +27,10 @@ import (
 	"go.opentelemetry.io/obi/pkg/app/request"
 	ebpfcommon "go.opentelemetry.io/obi/pkg/components/ebpf/common"
 	"go.opentelemetry.io/obi/pkg/components/exec"
-	"go.opentelemetry.io/obi/pkg/components/goexec"
 	"go.opentelemetry.io/obi/pkg/components/imetrics"
 	"go.opentelemetry.io/obi/pkg/components/svc"
 	"go.opentelemetry.io/obi/pkg/config"
+	"go.opentelemetry.io/obi/pkg/internal/goexec"
 	"go.opentelemetry.io/obi/pkg/obi"
 	"go.opentelemetry.io/obi/pkg/pipe/msg"
 )
@@ -181,6 +181,11 @@ func (p *Tracer) RegisterOffsets(fileInfo *exec.FileInfo, offsets *goexec.Offset
 		goexec.GoTracerDelegatePos,
 		// go jsonrpc
 		goexec.GoJsonrpcRequestHeaderServiceMethodPos,
+		// go mongodb
+		goexec.MongoConnNamePos,
+		goexec.MongoOpNamePos,
+		goexec.MongoOpDBPos,
+		goexec.MongoOneThirteenOne,
 	} {
 		if val, ok := offsets.Field[field].(uint64); ok {
 			offTable.Table[field] = val
@@ -447,6 +452,82 @@ func (p *Tracer) GoProbes() map[string][]*ebpfcommon.ProbeDesc {
 		"go.opentelemetry.io/auto/sdk.(*span).RecordError": {{
 			Start: p.bpfObjects.ObiUprobeRecordError,
 		}},
+		// Go MongoDB
+		"go.mongodb.org/mongo-driver/x/mongo/driver.Operation.Execute": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpExecute,
+			End:   p.bpfObjects.ObiUprobeMongoOpExecuteRet,
+		}},
+		"go.mongodb.org/mongo-driver/v2/x/mongo/driver.Operation.Execute": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpExecute,
+			End:   p.bpfObjects.ObiUprobeMongoOpExecuteRet,
+		}},
+		// all of these point to the same probe, we just use it to find start time and collection name
+		"go.mongodb.org/mongo-driver/mongo.(*Collection).insert": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpInsert,
+		}},
+		"go.mongodb.org/mongo-driver/v2/mongo.(*Collection).insert": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpInsert,
+		}},
+		"go.mongodb.org/mongo-driver/mongo.(*Collection).delete": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpDelete,
+		}},
+		"go.mongodb.org/mongo-driver/v2/mongo.(*Collection).delete": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpDelete,
+		}},
+		"go.mongodb.org/mongo-driver/mongo.(*Collection).updateOrReplace": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpUpdateOrReplace,
+		}},
+		"go.mongodb.org/mongo-driver/v2/mongo.(*Collection).updateOrReplace": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpUpdateOrReplace,
+		}},
+		"go.mongodb.org/mongo-driver/mongo.(*Collection).find": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpFind,
+		}},
+		"go.mongodb.org/mongo-driver/v2/mongo.(*Collection).find": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpFind,
+		}},
+		"go.mongodb.org/mongo-driver/mongo.(*Collection).Find": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpFind,
+		}},
+		"go.mongodb.org/mongo-driver/v2/mongo.(*Collection).Find": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpFind,
+		}},
+		"go.mongodb.org/mongo-driver/mongo.(*Collection).drop": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpDrop,
+		}},
+		"go.mongodb.org/mongo-driver/v2/mongo.(*Collection).drop": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpDrop,
+		}},
+		"go.mongodb.org/mongo-driver/mongo.(*Collection).findAndModify": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpFindAndModify,
+		}},
+		"go.mongodb.org/mongo-driver/v2/mongo.(*Collection).findAndModify": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpFindAndModify,
+		}},
+		"go.mongodb.org/mongo-driver/mongo.(*Collection).Aggregate": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpAggregate,
+		}},
+		"go.mongodb.org/mongo-driver/v2/mongo.(*Collection).Aggregate": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpAggregate,
+		}},
+		"go.mongodb.org/mongo-driver/mongo.(*Collection).CountDocuments": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpCountDocuments,
+		}},
+		"go.mongodb.org/mongo-driver/v2/mongo.(*Collection).CountDocuments": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpCountDocuments,
+		}},
+		"go.mongodb.org/mongo-driver/mongo.(*Collection).EstimatedDocumentCount": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpEstimatedDocumentCount,
+		}},
+		"go.mongodb.org/mongo-driver/v2/mongo.(*Collection).EstimatedDocumentCount": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpEstimatedDocumentCount,
+		}},
+		"go.mongodb.org/mongo-driver/mongo.(*Collection).Distinct": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpDistinct,
+		}},
+		"go.mongodb.org/mongo-driver/v2/mongo.(*Collection).Distinct": {{
+			Start: p.bpfObjects.ObiUprobeMongoOpDistinct,
+		}},
 	}
 
 	if p.supportsContextPropagation() {
@@ -507,6 +588,7 @@ func (p *Tracer) AlreadyInstrumentedLib(_ uint64) bool {
 func (p *Tracer) Run(ctx context.Context, ebpfEventContext *ebpfcommon.EBPFEventContext, eventsChan *msg.Queue[[]request.Span]) {
 	ebpfcommon.SharedRingbuf(
 		ebpfEventContext,
+		ebpfcommon.NewEBPFParseContext(p.cfg),
 		p.cfg,
 		p.pidsFilter,
 		p.bpfObjects.Events,
